@@ -1,4 +1,4 @@
-CONFIG_FILE = 'grammars/settings.ini'
+CONFIG_FILE = 'settings.ini'
 
 SPECIAL_KEYS = {
 	'alt': 'alt',
@@ -23,7 +23,7 @@ NUMBERS_MAP = {
 	'too': '2',
 	'for': '4',
 	"i've": '5',
-        'sex': '6',
+    'sex': '6',
 }
 
 
