@@ -1,4 +1,5 @@
 import subprocess
+import configparser
 import os
 try:
     import constants
@@ -48,3 +49,15 @@ def split_send_string(string_to_send):
         else:
             split_string[-1] += char
     return split_string
+
+def get_shared_directory(path):
+    config = configparser.ConfigParser()
+    config.read(path)
+    return(config['settings']['shared_dir'])
+
+def save_directory(path, value):
+    config = configparser.ConfigParser()
+    config.read(path)
+    config['settings']['shared_dir'] = value
+    with open(path, 'w') as configfile:
+        config.write(configfile)
\ No newline at end of file
